@@ -1,17 +1,23 @@
 /*
  * status.cpp
- * Copyright (C) 1999-2002 Kurt Granroth <granroth@kde.org>
+ * Copyright (C) 1999-2005 Kurt Granroth <granroth@kde.org>
  *
  * This file contains the implementation of the KBiffStatus
  * widget
  *
- * $Id: status.cpp,v 1.7 2002/11/02 03:36:35 gran Exp $
+ * $Id: status.cpp,v 1.9 2005/09/10 21:35:05 gran Exp $
  */
 #include "status.h"
 
 #include <kapp.h>
 #include <klocale.h>
 
+#ifdef QT_VERSION >= 0x030000
+#include <qdesktopwidget.h>
+#include <qpoint.h>
+#include <qrect.h>
+#endif
+
 #include <qheader.h>
 #include <qlabel.h>
 #include <qlayout.h>
@@ -74,19 +80,39 @@ void KBiffStatus::updateListView(const KBiffStatusList& list)
 
 void KBiffStatus::popup(const QPoint& pos)
 {
+#ifdef QT_VERSION >= 0x030000
+    QDesktopWidget *desktop = KApplication::desktop();
+#else
     QWidget *desktop = KApplication::desktop();
+#endif
     int x = pos.x(), y = pos.y();
 
     // for some reason, the width and height are incorrect until
     // we do the show.  so we show first (after hiding) and move later
     move(-100, -100);
     show();
-
-    // verify that the width is within the desktop
-    if ((pos.x() + width()) > desktop->width())
+ 
+#ifdef QT_VERSION >= 0x030000
+    // verify that the width is within the desktop  
+    if (desktop->isVirtualDesktop())
     {
-        x = pos.x() - width();
-        x = (x < 0) ? 0 : x;
+	QRect scn = desktop->screenGeometry(QPoint(x, y));
+		
+	if ((pos.x() + width()) > scn.width())
+        {
+            //x = pos.x() - width();
+	    x = scn.width() - width();
+            x = (x < 0) ? 0 : x;
+        }
+    }   
+    else
+#endif
+    {
+        if ((pos.x() + width()) > desktop->width())
+	{
+	    x = pos.x() - width();
+	    x = (x < 0) ? 0 : x;
+        }
     }
 
     // verify that that height is within tolerances
